@@ -1,21 +1,9 @@
 /*
  *  alarmlistview.h  -  widget showing list of alarms
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef ALARMLISTVIEW_H
@@ -31,7 +19,10 @@ class AlarmListView : public EventListView
     Q_OBJECT
 public:
     explicit AlarmListView(const QByteArray& configGroup, QWidget* parent = nullptr);
+
+    /** Return which of the optional columns are currently shown. */
     QList<bool> columnsVisible() const;
+
     void        setColumnsVisible(const QList<bool>& show);
 
 Q_SIGNALS:
@@ -43,9 +34,11 @@ protected Q_SLOTS:
 private Q_SLOTS:
     void        saveColumnsState();
     void        headerContextMenuRequested(const QPoint&);
+    void        useAlarmNameChanged(bool);
 
 private:
     void        showHideColumn(QMenu&, QAction*);
+    void        setReplaceBlankName();
     void        enableTimeColumns(QMenu*);
 
     QByteArray  mConfigGroup;
