@@ -1,21 +1,9 @@
 /*
  *  find.cpp  -  search facility
  *  Program:  kalarm
- *  Copyright © 2005-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "find.h"
@@ -104,11 +92,11 @@ void Find::display()
         QWidget* kalarmWidgets = mDialog->findExtension();
 
         // Alarm types
-        QVBoxLayout* layout = new QVBoxLayout(kalarmWidgets);
+        auto* layout = new QVBoxLayout(kalarmWidgets);
         layout->setContentsMargins(0, 0, 0, 0);
         QGroupBox* group = new QGroupBox(i18nc("@title:group", "Alarm Type"), kalarmWidgets);
         layout->addWidget(group);
-        QGridLayout* grid = new QGridLayout(group);
+        auto* grid = new QGridLayout(group);
         grid->setColumnStretch(1, 1);
 
         // Live & archived alarm selection
