@@ -1,21 +1,9 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "functions.h"
@@ -23,11 +11,10 @@
 
 #include "akonadicollectionsearch.h"
 #include "displaycalendar.h"
-#include "editdlg.h"
 #include "kalarmapp.h"
 #include "kamail.h"
 #include "mainwindow.h"
-#include "messagewin.h"
+#include "messagewindow.h"
 #include "preferences.h"
 #include "resourcescalendar.h"
 #include "templatelistview.h"
@@ -45,7 +32,6 @@
 
 #include <kalarmcal_version.h>
 #include <KAlarmCal/Identities>
-#include <KAlarmCal/KAEvent>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
@@ -80,6 +66,7 @@ using namespace KCalendarCore;
 #include <QPushButton>
 #include <QTemporaryFile>
 
+//clazy:excludeall=non-pod-global-static
 
 namespace
 {
@@ -212,7 +199,7 @@ KToggleAction* createAlarmEnableAction(QObject* parent)
 QAction* createStopPlayAction(QObject* parent)
 {
     QAction* action = new QAction(QIcon::fromTheme(QStringLiteral("media-playback-stop")), i18nc("@action", "Stop Play"), parent);
-    action->setEnabled(MessageWin::isAudioPlaying());
+    action->setEnabled(MessageDisplay::isAudioPlaying());
     QObject::connect(action, &QAction::triggered, theApp(), &KAlarmApp::stopAudio);
     // The following line ensures that all instances are kept in the same state
     QObject::connect(theApp(), &KAlarmApp::audioPlaying, action, &QAction::setEnabled);
@@ -739,10 +726,10 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
                 resourceIds.insert(event->resourceId());
                 ResourcesCalendar::disabledChanged(newev);
 
-                // If we're disabling a display alarm, close any message window
+                // If we're disabling a display alarm, close any message display
                 if (!enable  &&  (event->actionTypes() & KAEvent::ACT_DISPLAY))
                 {
-                    MessageWin* win = MessageWin::findEvent(EventId(*event));
+                    MessageDisplay* win = MessageDisplay::findEvent(EventId(*event));
                     delete win;
                 }
             }
@@ -1227,11 +1214,7 @@ QStringList checkRtcWakeConfig(bool checkEventExists)
 {
     KConfigGroup config(KSharedConfig::openConfig(), "General");
     const QStringList params = config.readEntry("RtcWake", QStringList());
-#if KALARMCAL_VERSION >= QT_VERSION_CHECK(5,12,1)
     if (params.count() == 3  &&  params[2].toLongLong() > KADateTime::currentUtcDateTime().toSecsSinceEpoch())
-#else
-    if (params.count() == 3  &&  params[2].toUInt() > KADateTime::currentUtcDateTime().toTime_t())
-#endif
     {
         if (checkEventExists)
         {
@@ -1623,13 +1606,13 @@ void refreshAlarmsIfQueued()
         for (Resource& resource : resources)
             resource.reload();
 
-        // Close any message windows for alarms which are now disabled
+        // Close any message displays for alarms which are now disabled
         const QVector<KAEvent> events = ResourcesCalendar::events(CalEvent::ACTIVE);
         for (const KAEvent& event : events)
         {
             if (!event.enabled()  &&  (event.actionTypes() & KAEvent::ACT_DISPLAY))
             {
-                MessageWin* win = MessageWin::findEvent(EventId(event));
+                MessageDisplay* win = MessageDisplay::findEvent(EventId(event));
                 delete win;
             }
         }
@@ -1675,7 +1658,7 @@ QStringList dontShowErrors(const EventId& eventId)
 {
     if (eventId.isEmpty())
         return QStringList();
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     return group.readEntry(id, QStringList());
@@ -1701,7 +1684,7 @@ void setDontShowErrors(const EventId& eventId, const QStringList& tags)
 {
     if (eventId.isEmpty())
         return;
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     if (tags.isEmpty())
@@ -1719,7 +1702,7 @@ void setDontShowErrors(const EventId& eventId, const QString& tag)
 {
     if (eventId.isEmpty()  ||  tag.isEmpty())
         return;
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     QStringList tags = group.readEntry(id, QStringList());
@@ -2028,7 +2011,7 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
     if (status != KAlarm::UPDATE_OK)
         return status;
     QDBusInterface korgInterface(KORG_DBUS_SERVICE, QStringLiteral(KORG_DBUS_PATH), KORG_DBUS_IFACE);
-    const QList<QVariant> args{iCal};
+    const QList<QVariant> args{iCal};             //clazy:exclude=inefficient-qlist
     QDBusReply<bool> reply = korgInterface.callWithArgumentList(QDBus::Block, QStringLiteral("addIncidence"), args);
     if (!reply.isValid())
     {
