@@ -1,21 +1,9 @@
 /*
  *  shellprocess.cpp  -  execute a shell process
  *  Program:  kalarm
- *  Copyright © 2004,2005,2007,2008 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "shellprocess.h"
@@ -53,11 +41,10 @@ bool ShellProcess::start(OpenMode openMode)
         return false;
     }
     connect(this, &QIODevice::bytesWritten, this, &ShellProcess::writtenStdin);
-    connect(this, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotExited(int,QProcess::ExitStatus)));
+    connect(this, &QProcess::finished, this, &ShellProcess::slotExited);
     connect(this, &QProcess::readyReadStandardOutput, this, &ShellProcess::stdoutReady);
     connect(this, &QProcess::readyReadStandardError, this, &ShellProcess::stderrReady);
-    QStringList args;
-    args << QStringLiteral("-c") << mCommand;
+    const QStringList args{ QStringLiteral("-c"), mCommand };
     QProcess::start(QLatin1String(shellName()), args, openMode);
     if (!waitForStarted())
     {
@@ -87,7 +74,7 @@ void ShellProcess::slotExited(int exitCode, QProcess::ExitStatus exitStatus)
     else
     {
         // Some shells report if the command couldn't be found, or is not executable
-        if ((mShellName == "bash"  &&  (exitCode == 126 || exitCode == 127))
+        if (((mShellName == "bash" || mShellName == "zsh")  &&  (exitCode == 126 || exitCode == 127))
         ||  (mShellName == "ksh"  &&  exitCode == 127))
         {
             qCWarning(KALARM_LOG) << "ShellProcess::slotExited:" << mCommand << ":" << mShellName << ": not found or not executable";
@@ -107,8 +94,8 @@ void ShellProcess::writeStdin(const char* buffer, int bufflen)
     mStdinQueue.enqueue(scopy);
     if (doWrite)
     {
-        mStdinBytes = mStdinQueue.head().length();
-        write(mStdinQueue.head());
+        mStdinBytes = qAsConst(mStdinQueue).head().length();
+        write(qAsConst(mStdinQueue).head());
     }
 }
 
@@ -127,8 +114,8 @@ void ShellProcess::writtenStdin(qint64 bytes)
         mStdinQueue.dequeue();   // free the buffer which has now been written
     if (!mStdinQueue.isEmpty())
     {
-        mStdinBytes = mStdinQueue.head().length();
-        write(mStdinQueue.head());
+        mStdinBytes = qAsConst(mStdinQueue).head().length();
+        write(qAsConst(mStdinQueue).head());
     }
     else if (mStdinExit)
         kill();
@@ -156,8 +143,9 @@ QString ShellProcess::errorMessage() const
         case UNAUTHORISED:
             return i18nc("@info", "Failed to execute command (shell access not authorized)");
         case START_FAIL:
-        case NOT_FOUND:
             return i18nc("@info", "Failed to execute command");
+        case NOT_FOUND:
+            return i18nc("@info", "Failed to execute command (not found or not executable)");
         case DIED:
             return i18nc("@info", "Command execution error");
         case SUCCESS:
