@@ -1,21 +1,9 @@
 /*
  *  fileresourcedatamodel.cpp  -  model containing file system resources and their events
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "fileresourcedatamodel.h"
@@ -63,7 +51,7 @@ FileResourceDataModel* FileResourceDataModel::instance(QObject* parent)
 {
     if (!mInstance)
     {
-        FileResourceDataModel* inst = new FileResourceDataModel(parent);
+        auto* inst = new FileResourceDataModel(parent);
         mInstance = inst;
         mInstanceIsOurs = true;
         inst->initialise();
@@ -135,10 +123,10 @@ void FileResourceDataModel::initialise()
     }
 
     MinuteTimer::connect(this, SLOT(slotUpdateTimeTo()));
-    Preferences::connect(SIGNAL(archivedColourChanged(QColor)), this, SLOT(slotUpdateArchivedColour(QColor)));
-    Preferences::connect(SIGNAL(disabledColourChanged(QColor)), this, SLOT(slotUpdateDisabledColour(QColor)));
-    Preferences::connect(SIGNAL(holidaysChanged(KHolidays::HolidayRegion)), this, SLOT(slotUpdateHolidays()));
-    Preferences::connect(SIGNAL(workTimeChanged(QTime,QTime,QBitArray)), this, SLOT(slotUpdateWorkingHours()));
+    Preferences::connect(&Preferences::archivedColourChanged, this, &FileResourceDataModel::slotUpdateArchivedColour);
+    Preferences::connect(&Preferences::disabledColourChanged, this, &FileResourceDataModel::slotUpdateDisabledColour);
+    Preferences::connect(&Preferences::holidaysChanged, this, &FileResourceDataModel::slotUpdateHolidays);
+    Preferences::connect(&Preferences::workTimeChanged, this, &FileResourceDataModel::slotUpdateWorkingHours);
 }
 
 /******************************************************************************
@@ -209,7 +197,7 @@ QModelIndex FileResourceDataModel::resourceIndex(const Resource& resource) const
         if (row >= 0)
             return createIndex(row, 0, mResourceNodes.value(Resource()).at(row));
     }
-    return QModelIndex();
+    return {};
 }
 
 /******************************************************************************
@@ -271,7 +259,7 @@ QModelIndex FileResourceDataModel::eventIndex(const QString& eventId) const
                 return createIndex(row, 0, node);
         }
     }
-    return QModelIndex();
+    return {};
 }
 
 /******************************************************************************
@@ -494,11 +482,12 @@ void FileResourceDataModel::slotEventsAdded(Resource& resource, const QList<KAEv
         {
             QVector<Node*>& resourceEventNodes = mResourceNodes[resource];
             int row = resourceEventNodes.count();
+            resourceEventNodes.reserve(row + eventsToAdd.count());
             const QModelIndex resourceIx = resourceIndex(resource);
             beginInsertRows(resourceIx, row, row + eventsToAdd.count() - 1);
             for (const KAEvent& event : qAsConst(eventsToAdd))
             {
-                KAEvent* ev = new KAEvent(event);
+                auto* ev = new KAEvent(event);
                 ev->setResourceId(resource.id());
                 Node* node = new Node(ev, resource);
                 resourceEventNodes += node;
@@ -516,8 +505,8 @@ void FileResourceDataModel::slotEventsAdded(Resource& resource, const QList<KAEv
 */
 void FileResourceDataModel::slotEventUpdated(Resource& resource, const KAEvent& event)
 {
-    auto it = mEventNodes.find(event.id());
-    if (it != mEventNodes.end())
+    auto it = mEventNodes.constFind(event.id());
+    if (it != mEventNodes.constEnd())
     {
         Node* node = it.value();
         if (node  &&  node->parent() == resource)
@@ -555,6 +544,7 @@ bool FileResourceDataModel::deleteEvents(Resource& resource, const QList<KAEvent
 
     // Find the row numbers of the events to delete.
     QVector<int> rowsToDelete;
+    rowsToDelete.reserve(events.count());
     for (const KAEvent& event : events)
     {
         Node* node = mEventNodes.value(event.id(), nullptr);
@@ -624,6 +614,7 @@ void FileResourceDataModel::addResource(Resource& resource)
     if (!events.isEmpty())
     {
         QVector<Node*>& resourceEventNodes = mResourceNodes[resource];
+        resourceEventNodes.reserve(resourceEventNodes.count() + events.count());
         for (const KAEvent& event : events)
         {
             Node* node = new Node(new KAEvent(event), resource);
@@ -808,7 +799,7 @@ TemplateListModel* FileResourceDataModel::allTemplateListModel()
 int FileResourceDataModel::rowCount(const QModelIndex& parent) const
 {
     if (!parent.isValid())
-        return mResourceNodes.keys().count() - 1;
+        return mResourceNodes.count() - 1;
     const Node* node = reinterpret_cast<Node*>(parent.internalPointer());
     if (node  &&  node->type == Type::Resource)
         return mResourceNodes.value(node->resource()).count();
@@ -861,7 +852,7 @@ QModelIndex FileResourceDataModel::index(int row, int column, const QModelIndex&
             }
         }
     }
-    return QModelIndex();
+    return {};
 }
 
 /******************************************************************************
@@ -880,7 +871,7 @@ QModelIndex FileResourceDataModel::parent(const QModelIndex& ix) const
                 return createIndex(row, 0, mResourceNodes.value(Resource()).at(row));
         }
     }
-    return QModelIndex();
+    return {};
 }
 
 /******************************************************************************
@@ -892,7 +883,7 @@ QModelIndexList FileResourceDataModel::match(const QModelIndex& start, int role,
     {
         case ResourceIdRole:
         {
-            QModelIndexList result;
+            QModelIndexList result;               //clazy:exclude=inefficient-qlist
             const ResourceId id = value.toLongLong();
             if (id >= 0)
             {
@@ -904,7 +895,7 @@ QModelIndexList FileResourceDataModel::match(const QModelIndex& start, int role,
         }
         case EventIdRole:
         {
-            QModelIndexList result;
+            QModelIndexList result;               //clazy:exclude=inefficient-qlist
             const QModelIndex ix = eventIndex(value.toString());
             if (ix.isValid())
                 result += ix;
