@@ -1,21 +1,9 @@
 /*
  *  resourcemodel.cpp  -  models containing flat list of resources
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resourcemodel.h"
@@ -83,7 +71,7 @@ void ResourceFilterModel::setFilterText(const QString& text)
 QModelIndex ResourceFilterModel::resourceIndex(const Resource& resource) const
 {
     if (!mResourceIndexFunction)
-        return QModelIndex();
+        return {};
     return mapFromSource((*mResourceIndexFunction)(resource));
 }
 
@@ -103,8 +91,8 @@ QModelIndexList ResourceFilterModel::match(const QModelIndex& start, int role, c
     if (role < Qt::UserRole)
         return QSortFilterProxyModel::match(start, role, value, hits, flags);
 
-    QModelIndexList matches;
-    const QModelIndexList indexes = sourceModel()->match(mapToSource(start), role, value, hits, flags);
+    QModelIndexList matches;            //clazy:exclude=inefficient-qlist
+    const QModelIndexList indexes = sourceModel()->match(mapToSource(start), role, value, hits, flags);     //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : indexes)
     {
         QModelIndex proxyIndex = mapFromSource(ix);
@@ -389,7 +377,7 @@ void ResourceCheckListModel::selectionChanged(const QItemSelection& selected, co
 {
     if (mResetting  ||  mDisabled)
         return;
-    const QModelIndexList sel = selected.indexes();
+    const QModelIndexList sel = selected.indexes();           //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : sel)
     {
         // Try to enable the resource, but untick it if not possible
@@ -398,7 +386,7 @@ void ResourceCheckListModel::selectionChanged(const QItemSelection& selected, co
         if (!resource.isEnabled(mAlarmType))
             mSelectionModel->select(ix, QItemSelectionModel::Deselect);
     }
-    const QModelIndexList desel = deselected.indexes();
+    const QModelIndexList desel = deselected.indexes();       //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : desel)
         mModel->resource(ix).setEnabled(mAlarmType, false);
 }
@@ -633,11 +621,6 @@ ResourceFilterCheckListModel* ResourceView::resourceModel() const
     return static_cast<ResourceFilterCheckListModel*>(model());
 }
 
-void ResourceView::setModel(QAbstractItemModel* model)
-{
-    QListView::setModel(model);
-}
-
 /******************************************************************************
 * Return the resource for a given row.
 */
