@@ -1,21 +1,9 @@
 /*
  *  resourcemodel.h  -  models containing flat list of resources
  *  Program:  kalarm
- *  Copyright © 2010-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2010-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef RESOURCEMODEL_H
@@ -244,7 +232,6 @@ public:
     Resource  resource(const QModelIndex&) const;
 
 protected:
-    void setModel(QAbstractItemModel*) override;
     void mouseReleaseEvent(QMouseEvent*) override;
     bool viewportEvent(QEvent*) override;
 };
@@ -257,7 +244,7 @@ protected:
 template <class DataModel>
 ResourceFilterModel* ResourceFilterModel::create(QObject* parent)
 {
-    ResourceFilterModel* model = new ResourceFilterModel(parent);
+    auto* model = new ResourceFilterModel(parent);
     model->setSourceModel(DataModel::instance());
     model->mResourceIndexFunction = [](const Resource& r) { return DataModel::instance()->resourceIndex(r); };
     return model;
@@ -266,7 +253,7 @@ ResourceFilterModel* ResourceFilterModel::create(QObject* parent)
 template <class DataModel>
 ResourceListModel* ResourceListModel::create(QObject* parent)
 {
-    ResourceListModel* model = new ResourceListModel(parent);
+    auto* model = new ResourceListModel(parent);
     model->setSourceModel(ResourceFilterModel::create<DataModel>(model));
     return model;
 }
@@ -274,7 +261,7 @@ ResourceListModel* ResourceListModel::create(QObject* parent)
 template <class DataModel>
 ResourceCheckListModel* ResourceCheckListModel::create(CalEvent::Type type, QObject* parent)
 {
-    ResourceCheckListModel* model = new ResourceCheckListModel(type, parent);
+    auto* model = new ResourceCheckListModel(type, parent);
     if (!mModel)
         mModel = ResourceListModel::create<DataModel>(nullptr);
     model->init();
