@@ -1,25 +1,13 @@
 /*
  *  resourceselector.cpp  -  calendar resource selection widget
  *  Program:  kalarm
- *  Copyright © 2006-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2006-2020 David Jarvie <djarvie@kde.org>
  *  Based on KOrganizer's ResourceView class and KAddressBook's ResourceSelection class,
- *  Copyright (C) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
- *  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
- *  Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>
+ *  SPDX-FileCopyrightText: 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
+ *  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+ *  SPDX-FileCopyrightText: 2004 Tobias Koenig <tokoe@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resourceselector.h"
@@ -93,7 +81,9 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     blayout->addWidget(mAddButton);
     blayout->addWidget(mEditButton);
     blayout->addWidget(mDeleteButton);
-    mEditButton->setWhatsThis(i18nc("@info:whatsthis", "Edit the highlighted calendar"));
+    mEditButton->setToolTip(i18nc("@info:tooltip", "Reconfigure the selected calendar"));
+    mEditButton->setWhatsThis(i18nc("@info:whatsthis", "Edit the highlighted calendar's configuration"));
+    mDeleteButton->setToolTip(i18nc("@info:tooltip", "Remove the selected calendar from the list"));
     mDeleteButton->setWhatsThis(xi18nc("@info:whatsthis", "<para>Remove the highlighted calendar from the list.</para>"
                                      "<para>The calendar itself is left intact, and may subsequently be reinstated in the list if desired.</para>"));
     mEditButton->setDisabled(true);
@@ -102,10 +92,10 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     connect(mEditButton, &QPushButton::clicked, this, &ResourceSelector::editResource);
     connect(mDeleteButton, &QPushButton::clicked, this, &ResourceSelector::removeResource);
 
-    connect(mAlarmType, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &ResourceSelector::alarmTypeSelected);
-    QTimer::singleShot(0, this, SLOT(alarmTypeSelected()));
+    connect(mAlarmType, &QComboBox::activated, this, &ResourceSelector::alarmTypeSelected);
+    QTimer::singleShot(0, this, &ResourceSelector::alarmTypeSelected);
 
-    Preferences::connect(SIGNAL(archivedKeepDaysChanged(int)), this, SLOT(archiveDaysChanged(int)));
+    Preferences::connect(&Preferences::archivedKeepDaysChanged, this, &ResourceSelector::archiveDaysChanged);
 }
 
 /******************************************************************************
@@ -286,7 +276,7 @@ void ResourceSelector::removeResource()
 */
 void ResourceSelector::selectionChanged()
 {
-    bool state = mListView->selectionModel()->selectedRows().count();
+    bool state = !mListView->selectionModel()->selectedRows().isEmpty();
     mDeleteButton->setEnabled(state);
     mEditButton->setEnabled(state);
 }
