@@ -1,26 +1,13 @@
 /*
  *  templatedlg.cpp  -  dialog to create, edit and delete alarm templates
  *  Program:  kalarm
- *  Copyright © 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "templatedlg.h"
 
-#include "editdlg.h"
 #include "functions.h"
 #include "newalarmaction.h"
 #include "resourcescalendar.h"
@@ -87,38 +74,42 @@ TemplateDlg::TemplateDlg(QWidget* parent)
     mNewAction = new NewAlarmAction(true, i18nc("@action", "New"), this);
     button->setMenu(mNewAction->menu());
     connect(mNewAction, &NewAlarmAction::selected, this, &TemplateDlg::slotNew);
+    button->setToolTip(i18nc("@info:tooltip", "Create a new alarm template"));
     button->setWhatsThis(i18nc("@info:whatsthis", "Create a new alarm template"));
     layout->addWidget(button);
 
     mEditButton = new QPushButton(i18nc("@action:button", "Edit..."));
     connect(mEditButton, &QPushButton::clicked, this, &TemplateDlg::slotEdit);
+    mEditButton->setToolTip(i18nc("@info:tooltip", "Edit the selected alarm template"));
     mEditButton->setWhatsThis(i18nc("@info:whatsthis", "Edit the currently highlighted alarm template"));
     layout->addWidget(mEditButton);
 
     mCopyButton = new QPushButton(i18nc("@action:button", "Copy"));
     connect(mCopyButton, &QPushButton::clicked, this, &TemplateDlg::slotCopy);
+    mCopyButton->setToolTip(i18nc("@info:tooltip", "Create a new alarm template based on the selected template"));
     mCopyButton->setWhatsThis(i18nc("@info:whatsthis", "Create a new alarm template based on a copy of the currently highlighted template"));
     layout->addWidget(mCopyButton);
 
     mDeleteButton = new QPushButton(i18nc("@action:button", "Delete"));
     connect(mDeleteButton, &QPushButton::clicked, this, &TemplateDlg::slotDelete);
-    mDeleteButton->setWhatsThis(i18nc("@info:whatsthis", "Delete the currently highlighted alarm template"));
+    mDeleteButton->setToolTip(i18nc("@info:tooltip", "Delete the selected alarm templates"));
+    mDeleteButton->setWhatsThis(i18nc("@info:whatsthis", "Delete the currently highlighted alarm templates"));
     layout->addWidget(mDeleteButton);
 
     layout->addStretch();
 
     topLayout->addWidget(new KSeparator(Qt::Horizontal, this));
 
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
+    auto* buttonBox = new QDialogButtonBox(this);
     buttonBox->addButton(QDialogButtonBox::Close);
     connect(buttonBox, &QDialogButtonBox::rejected,
             this, &QDialog::close);
     topLayout->addWidget(buttonBox);
 
     KActionCollection* actions = new KActionCollection(this);
-    QAction* act = KStandardAction::selectAll(mListView, SLOT(selectAll()), actions);
+    QAction* act = KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
     topLevelWidget()->addAction(act);
-    act = KStandardAction::deselect(mListView, SLOT(clearSelection()), actions);
+    act = KStandardAction::deselect(mListView, &QAbstractItemView::clearSelection, actions);
     topLevelWidget()->addAction(act);
     slotSelectionChanged();          // enable/disable buttons as appropriate
 
@@ -192,7 +183,9 @@ void TemplateDlg::slotDelete()
         return;
 
     KAEvent::List delEvents;
+    delEvents.reserve(n);
     Undo::EventList undos;
+    undos.reserve(n);
     for (int i = 0;  i < n;  ++i)
     {
         KAEvent* event = &events[i];
